function varargout = RIP(varargin)
% RIP M-file for RIP.fig
%      RIP, by itself, creates a new RIP or raises the existing
%      singleton*.
%
%      H = RIP returns the handle to a new RIP or the handle to
%      the existing singleton*.
%
%      RIP('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in RIP.M with the given input arguments.
%
%      RIP('Property','Value',...) creates a new RIP or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before RIP_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to RIP_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help RIP

% Last Modified by GUIDE v2.5 03-May-2011 14:18:55

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @RIP_OpeningFcn, ...
                   'gui_OutputFcn',  @RIP_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before RIP is made visible.
function RIP_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to RIP (see VARARGIN)

% Choose default command line output for RIP
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes RIP wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = RIP_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


function davkove_pushbutton_Callback(hObject, eventdata, handles)
Subgui_davkove()
guidata(hObject, handles);

function jedno_snimek_pushbutton_Callback(hObject, eventdata, handles)
Subgui_jednotlive()
guidata(hObject, handles);
